/* -*- Mode: C; tab-width: 4; indent-tabs-mode: t; c-basic-offset: 4 -*- */
/* NetworkManager system settings service
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * (C) Copyright 2008 - 2019 Mikhail Efremov <sem@altlinux.org>
 */

#ifndef __COMMON_H__
#define __COMMON_H__

#include "nm-default.h"

#include <glib.h>
#include "nm-core-internal.h"
#include "nm-logging.h"
#include "nm-types.h"
#include "settings/nm-settings-plugin.h"

#define ETCNET_PLUGIN_NAME "etcnet-alt"

#define PLUGIN_INFO(fstr, args...) nm_log_info (LOGD_SETTINGS, ETCNET_PLUGIN_NAME ": " fstr, ##args)
#define PLUGIN_DEBUG(fstr, args...) nm_log_dbg (LOGD_SETTINGS, ETCNET_PLUGIN_NAME ": %s, line %d: " fstr, __func__, __LINE__, ##args)
#define PLUGIN_WARNING(fstr, args...) nm_log_warn (LOGD_SETTINGS, ETCNET_PLUGIN_NAME ": " fstr, ##args)
#define PLUGIN_ERROR(str, error) PLUGIN_WARNING("%s: %s", str, error && error->message ? error->message : "(unknown)")

#define PLUGIN_SET_ERROR(error, fstr, args...) g_set_error ((error), NM_SETTINGS_ERROR, NM_SETTINGS_ERROR_INVALID_CONNECTION, fstr, ##args)
#define PLUGIN_SET_ERROR_LITERAL(error, str) g_set_error_literal ((error), NM_SETTINGS_ERROR, NM_SETTINGS_ERROR_INVALID_CONNECTION, str)

char *get_iface_name (const char *iface_path);
char *get_filename_with_profile(const char *file, const char *profile);

#endif  /* __COMMON_H__ */
